@@ -26,4 +26,4 @@ def add_routes(this_app):
     this_app.include_router(background_router)
 
 
-# add_routes(app)
+add_routes(app)
